==> lalapps-6.26.0.tar.xz: lalapps-6.26.0/README.md <==
# LALApps

Collection of gravitational wave data analysis codes and pipelines
utilising the LAL libraries.

## Acknowledgment

We request that any academic report, publication, or other academic
disclosure of results derived from the use of this software acknowledge
the use of the software by an appropriate acknowledgment or citation.

The whole LALSuite software suite can be cited with the DOI
[10.7935/GT1W-FZ16][doi]. An example BibTeX entry could look like this:

     @misc{lalsuite,
           author         = "{LIGO Scientific Collaboration}",
           title          = "{LIGO} {A}lgorithm {L}ibrary - {LALS}uite",
           howpublished   = "free software (GPL)",
           doi            = "10.7935/GT1W-FZ16",
           year           = "2018"
     }

In addition, some codes contained in this package may be directly based
on one or several scientific papers, which should be cited when using
those specific codes; some of these can be discovered through the
documentation.

## Basic Build Instructions

     ./configure --prefix=...
     make
     make install

Please read the [LALSuite install how-to][install] for more detailed
build instructions.

## Bug Reporting

Please visit the [LALSuite bug reporting system][bugs] (LIGO.org
authentication required to submit new issues), or use the [e-mail
helpdesk][helpdesk].

## For More Information

Please visit the [LALSuite project page][project].

[doi]:          https://doi.org/10.7935/GT1W-FZ16
[helpdesk]:     mailto:contact+lscsoft-lalsuite-1438-issue-@support.ligo.org
[install]:      https://wiki.ligo.org/Computing/LALSuiteInstall
[bugs]:         https://git.ligo.org/lscsoft/lalsuite/issues/
[project]:      https://wiki.ligo.org/Computing/LALSuite

==> lalapps-10.0.1.tar.xz: lalapps-10.0.1/README.md <==
# LALApps

Collection of gravitational wave data analysis codes and pipelines
utilising the LAL libraries.

## Acknowledgment

We request that any academic report, publication, or other academic
disclosure of results derived from the use of this software acknowledge
the use of the software by an appropriate acknowledgment or citation.

The whole LALSuite software suite can be cited with the DOI
[10.7935/GT1W-FZ16][doi]. An example BibTeX entry could look like this:

     @misc{lalsuite,
           author         = "{LIGO Scientific Collaboration} and {Virgo Collaboration} and {KAGRA Collaboration}",
           title          = "{LVK} {A}lgorithm {L}ibrary - {LALS}uite",
           howpublished   = "Free software (GPL)",
           doi            = "10.7935/GT1W-FZ16",
           year           = "2018"
     }

In addition, some codes contained in this package may be directly based
on one or several scientific papers, which should be cited when using
those specific codes; some of these can be discovered through the
documentation.

## Basic Build Instructions

     ./configure --prefix=...
     make
     make install

Please read the [LALSuite install how-to][install] for more detailed
build instructions.

## Bug Reporting

Please visit the [LALSuite bug reporting system][bugs] (LIGO.org
authentication required to submit new issues), or use the [e-mail
helpdesk][helpdesk].

## For More Information

Please visit the [LALSuite project page][project].

[doi]:          https://doi.org/10.7935/GT1W-FZ16
[helpdesk]:     mailto:contact+lscsoft-lalsuite-1438-issue-@support.ligo.org
[install]:      https://wiki.ligo.org/Computing/LALSuiteInstall
[bugs]:         https://git.ligo.org/lscsoft/lalsuite/issues/
[project]:      https://wiki.ligo.org/Computing/LALSuite
